@@ -1,35 +1,23 @@
 package Net::Amazon::S3::Request::InitiateMultipartUpload;
-$Net::Amazon::S3::Request::InitiateMultipartUpload::VERSION = '0.84';
+$Net::Amazon::S3::Request::InitiateMultipartUpload::VERSION = '0.85';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
-extends 'Net::Amazon::S3::Request';
+extends 'Net::Amazon::S3::Request::Object';
 
-with 'Net::Amazon::S3::Role::Bucket';
-
-has 'key'        => ( is => 'ro', isa => 'Str',             required => 1 );
-has 'acl_short'  => ( is => 'ro', isa => 'Maybe[AclShort]', required => 0 );
 has 'headers' =>
     ( is => 'ro', isa => 'HashRef', required => 0, default => sub { {} } );
-has 'encryption' => ( is => 'ro', isa => 'Maybe[Str]',      required => 0 );
+
+with 'Net::Amazon::S3::Request::Role::Query::Action::Uploads';
+with 'Net::Amazon::S3::Request::Role::HTTP::Header::Acl_short';
+with 'Net::Amazon::S3::Request::Role::HTTP::Header::Encryption';
+with 'Net::Amazon::S3::Request::Role::HTTP::Method::POST';
 
 __PACKAGE__->meta->make_immutable;
 
-sub http_request {
-    my $self    = shift;
-    my $headers = $self->headers;
+sub _request_headers {
+    my ($self) = @_;
 
-    if ( $self->acl_short ) {
-        $headers->{'x-amz-acl'} = $self->acl_short;
-    }
-    if ( defined $self->encryption ) {
-        $headers->{'x-amz-server-side-encryption'} = $self->encryption;
-    }
-
-    return $self->_build_http_request(
-        method  => 'POST',
-        path    => $self->_uri( $self->key ).'?uploads',
-        headers => $self->headers,
-    );
+    return %{ $self->headers };
 }
 
 1;
@@ -44,7 +32,7 @@ Net::Amazon::S3::Request::InitiateMultipartUpload - An internal class to begin a
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 SYNOPSIS
 
