@@ -1,18 +1,18 @@
 package Net::Amazon::S3::Request::ListAllMyBuckets;
-$Net::Amazon::S3::Request::ListAllMyBuckets::VERSION = '0.84';
+$Net::Amazon::S3::Request::ListAllMyBuckets::VERSION = '0.85';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
-extends 'Net::Amazon::S3::Request';
+extends 'Net::Amazon::S3::Request::Service';
 
 # ABSTRACT: An internal class to list all buckets
 
+with 'Net::Amazon::S3::Request::Role::HTTP::Method::GET';
+
 __PACKAGE__->meta->make_immutable;
 
 sub http_request {
     my $self    = shift;
     return $self->_build_http_request(
-        method => 'GET',
-        path   => '',
         use_virtual_host => 0,
         authorization_method => 'Net::Amazon::S3::Signature::V2',
     );
@@ -32,7 +32,7 @@ Net::Amazon::S3::Request::ListAllMyBuckets - An internal class to list all bucke
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 SYNOPSIS
 
