@@ -1,50 +1,20 @@
 package Net::Amazon::S3::Request::ListBucket;
-$Net::Amazon::S3::Request::ListBucket::VERSION = '0.84';
+$Net::Amazon::S3::Request::ListBucket::VERSION = '0.85';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use URI::Escape qw(uri_escape_utf8);
-extends 'Net::Amazon::S3::Request';
+extends 'Net::Amazon::S3::Request::Bucket';
 
 # ABSTRACT: An internal class to list a bucket
 
-with 'Net::Amazon::S3::Role::Bucket';
-
-has 'prefix'    => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
-has 'delimiter' => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
-has 'max_keys' =>
-    ( is => 'ro', isa => 'Maybe[Int]', required => 0, default => 1000 );
-has 'marker' => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
+with 'Net::Amazon::S3::Request::Role::Query::Param::Delimiter';
+with 'Net::Amazon::S3::Request::Role::Query::Param::Marker';
+with 'Net::Amazon::S3::Request::Role::Query::Param::Max_keys';
+with 'Net::Amazon::S3::Request::Role::Query::Param::Prefix';
+with 'Net::Amazon::S3::Request::Role::HTTP::Method::GET';
 
 __PACKAGE__->meta->make_immutable;
 
-sub http_request {
-    my $self = shift;
-
-    my $path = $self->_uri;
-
-    my @post;
-    foreach my $method ( qw(prefix delimiter max_keys marker) ) {
-        my $value = $self->$method;
-        next unless $value;
-        my $key = $method;
-        $key = 'max-keys' if $method eq 'max_keys';
-        push @post, $key . "=" . $self->_urlencode($value);
-    }
-    if (@post) {
-        $path .= '?' . join( '&', @post );
-    }
-
-    return $self->_build_http_request(
-        method => 'GET',
-        path   => $path,
-    );
-}
-
-sub _urlencode {
-    my ( $self, $unencoded ) = @_;
-    return uri_escape_utf8( $unencoded, '^A-Za-z0-9_-' );
-}
-
 1;
 
 __END__
@@ -59,7 +29,7 @@ Net::Amazon::S3::Request::ListBucket - An internal class to list a bucket
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 SYNOPSIS
 
